VMAP interface for pyLife
=========================

`VMAP <https://www.vmap.eu.com/>`_ *is a vendor-neutral standard
for CAE data storage to enhance interoperability in virtual
engineering workflows.*

As for now, the VMAP support in pyLife is in an experimental stage. That is
mainly because there are not many other software packages available that do
support it. Nevertheless we would like to encourage the usage of VMAP, so we
decided to put the experimental code into the release.

pyLife supports a growing subset of the VMAP standard. That means that
only features relevant for pyLife's addressed real life use cases are
or will be implemented. Probably there are features missing, that are
important for some valid use cases. In that case please file a feature
request at https://github.com/boschresearch/pylife/issues
